<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Version details
 *
 * @package    block_iclicker
 * @copyright  2012 i>clicker (R) <http://www.iclicker.com/dnn/> onwards Saji Nair (http://sajinair.com)
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
/* $Id$ */

if (!defined('MOODLE_INTERNAL')) {
    die('Direct access to this script is forbidden.'); // It must be included from a Moodle page.
}

require_once(dirname(__FILE__) . '/../../../config.php');
global $CFG, $USER, $COURSE;
// link in external libraries
 /* * @noinspection PhpIncludeInspection */
require_once($CFG->libdir . '/gradelib.php');
// require_once ($CFG->dirroot.'/blocks/simplehtml/lib.php');
// grade perm: moodle/grade:manage

/** This class contains the test cases for the functions in iclicker_service.php. */

 /* * @noinspection PhpDeprecationInspection */
class iclicker_gradebook_test extends UnitTestCase {

    public $courseid = 1;

    public $studentid1 = 1;
    public $studentid2 = 2;

    public $catname = 'az_category';
    public $itemname = 'az_gradeitem';
    public $gradescore = 91;

    public function setUp() {
        // cleanup the cats and gradeitems and grades if any exist
        $gradecats = grade_category::fetch_all(array(
                        'courseid' => $this->courseid,
                        'fullname' => $this->catname
                )
        );
        if ($gradecats) {
            foreach ($gradecats as $cat) {
                $gradeitems = grade_item::fetch_all(array(
                                'courseid' => $this->courseid,
                                'categoryid' => $cat->id,
                                'itemname' => $this->itemname
                        )
                );
                if ($gradeitems) {
                    foreach ($gradeitems as $item) {
                        $grades = grade_grade::fetch_all(array(
                                        'itemid' => $item->id
                                )
                        );
                        if ($grades) {
                            foreach ($grades as $grade) {
                                $grade->delete("cleanup");
                            }
                        }
                        $item->delete("cleanup");
                    }
                }
                $cat->delete("cleanup");
            }
        }
    }

    public function tearDown() {
    }

    public function test_assert() {
        $this->assertEqual("AZ", "AZ");
    }

    public function test_gradebook() {
        $locationstr = 'manual';

        // try to get category
        $gradecategory = grade_category::fetch(array(
                        'courseid' => $this->courseid,
                        'fullname' => $this->catname
                )
        );
        // NOTE: grade category will not be null but it will be empty
        $this->assertFalse($gradecategory);

        // create a category
        $params = new stdClass();
        $params->courseid = $this->courseid;
        $params->fullname = $this->catname;

        $gradecategory = new grade_category($params, false);
        $this->assertTrue(method_exists($gradecategory, 'insert'));
        $gradecategory->insert($locationstr);

        // now we will really get the category that we just made
        $gradecategoryfetched = grade_category::fetch(array(
                        'courseid' => $this->courseid,
                        'fullname' => $this->catname
                )
        );
        $this->assertTrue($gradecategoryfetched);
        $this->assertEqual($gradecategory->id, $gradecategoryfetched->id);
        $this->assertEqual($gradecategory->courseid, $gradecategoryfetched->courseid);
        $this->assertEqual($gradecategory->path, $gradecategoryfetched->path);
        $this->assertEqual($gradecategory->fullname, $gradecategoryfetched->fullname);
        $this->assertEqual($gradecategory->parent, $gradecategoryfetched->parent);

        // try to get grade item
        $gradeitem = grade_item::fetch(array(
                        'courseid' => $this->courseid,
                        'categoryid' => $gradecategory->id,
                        'itemname' => $this->itemname
                )
        );
        // NOTE: grade category will not be null but it will be empty
        $this->assertFalse($gradeitem);

        // create a grade item
        $gradeitem = new grade_item();
        $this->assertTrue(method_exists($gradeitem, 'insert'));

        $gradeitem->courseid = $this->courseid;
        $gradeitem->categoryid = $gradecategory->id;
        $gradeitem->idnumber = $this->itemname; // lookup
        $gradeitem->itemname = $this->itemname; // display
        $gradeitem->itemtype = 'blocks';
        $gradeitem->itemmodule = 'iclicker';
        $gradeitem->iteminfo = 'blocks/iclicker for unit testing';
        // grademax=100, grademin=0
        $gradeitem->grademax = 100.0;

        $gradeitem->insert($locationstr);

        // now we will really get the new item
        $gradeitemfetched = grade_item::fetch(array(
                        'courseid' => $this->courseid,
                        'categoryid' => $gradecategory->id,
                        'itemname' => $this->itemname
                )
        );
        $this->assertTrue($gradeitemfetched);
        $this->assertEqual($gradeitem->id, $gradeitemfetched->id);
        $this->assertEqual($gradeitem->courseid, $gradeitemfetched->courseid);
        $this->assertEqual($gradeitem->categoryid, $gradeitemfetched->categoryid);
        $this->assertEqual($gradeitem->itemname, $gradeitemfetched->itemname);

        // get empty grades list
        $allgrades = grade_grade::fetch_all(array(
                        'itemid' => $gradeitem->id
                )
        );
        $this->assertFalse($allgrades);

        // add grade
        $gradegrade = new grade_grade();
        $this->assertTrue(method_exists($gradegrade, 'insert'));
        $gradegrade->itemid = $gradeitem->id;
        $gradegrade->userid = $this->studentid1;
        $gradegrade->rawgrade = $this->gradescore;
        $gradegrade->insert($locationstr);

        // get new grade
        $gradegradefetched = grade_grade::fetch(array(
                        'itemid' => $gradeitem->id,
                        'userid' => $this->studentid1
                )
        );
        $this->assertTrue($gradegradefetched);
        $this->assertEqual($gradegrade->id, $gradegradefetched->id);
        $this->assertEqual($gradegrade->itemid, $gradegradefetched->itemid);
        $this->assertEqual($gradegrade->userid, $gradegradefetched->userid);
        $this->assertEqual($gradegrade->rawgrade, $gradegradefetched->rawgrade);

        // update the grade
        $gradegrade->rawgrade = 50;
        $result = $gradegrade->update($locationstr);
        $this->assertTrue($result);
        $gradegradefetched = grade_grade::fetch(array(
                        'id' => $gradegrade->id
                )
        );
        $this->assertTrue($gradegradefetched);
        $this->assertEqual($gradegrade->id, $gradegradefetched->id);
        $this->assertEqual($gradegrade->rawgrade, $gradegradefetched->rawgrade);
        $this->assertEqual(50, $gradegradefetched->rawgrade);

        // get grades
        $allgrades = grade_grade::fetch_all(array(
                        'itemid' => $gradeitem->id
                )
        );
        $this->assertTrue($allgrades);
        $this->assertEqual(1, count($allgrades));

        // add more grades
        $gradegrade2 = new grade_grade();
        $gradegrade2->itemid = $gradeitem->id;
        $gradegrade2->userid = $this->studentid2;
        $gradegrade2->rawgrade = $this->gradescore;
        $gradegrade2->insert($locationstr);

        // get grades
        $allgrades = grade_grade::fetch_all(array(
                        'itemid' => $gradeitem->id
                )
        );
        $this->assertTrue($allgrades);
        $this->assertEqual(2, count($allgrades));

        // make sure this can run
        $result = $gradeitem->regrade_final_grades();
        $this->assertTrue($result);

        // remove grades
        $this->assertTrue(method_exists($gradegrade, 'delete'));
        $result = $gradegrade->delete($locationstr);
        $this->assertTrue($result);
        $result = $gradegrade2->delete($locationstr);
        $this->assertTrue($result);

        // check no grades left
        $allgrades = grade_grade::fetch_all(array(
                        'itemid' => $gradeitem->id
                )
        );
        $this->assertFalse($allgrades);

        // remove grade item
        $this->assertTrue(method_exists($gradeitem, 'delete'));
        $result = $gradeitem->delete($locationstr);
        $this->assertTrue($result);

        // remove grade category
        $this->assertTrue(method_exists($gradecategory, 'delete'));
        $result = $gradecategory->delete($locationstr);
        $this->assertTrue($result);
    }

}
